<?php

namespace Cartimize\Compatibility\Plugins;

use Cartimize\Compatibility\Core;
use Cartimize\Cartimize;

class ExtraCheckoutFieldsBrazil extends Core {
	public function __construct() {
		parent::__construct();
	}

	public function is_available() {
		return class_exists( '\\Extra_Checkout_Fields_For_Brazil' );
	}

	public function pre_init() {
		if ( class_exists( '\\Extra_Checkout_Fields_For_Brazil' ) ) {
			add_filter( 'cartimize_get_billing_checkout_fields', array( $this, 'checkout_billing_fields' ) );
			add_filter( 'cartimize_get_shipping_checkout_fields', array( $this, 'checkout_shipping_fields' ) );
			add_filter( 'cartimize_force_display_billing_address', '__return_true' );
			add_filter( 'wcbcf_billing_fields', array( $this, 'wcbcf_checkout_billing_fields' ) );
			add_filter( 'wcbcf_shipping_fields', array( $this, 'wcbcf_checkout_shipping_fields' ) );
			add_filter( 'cartimize_get_billing_details_address', array( $this, 'add_additional_billing_fields' ), 10, 2 );
			add_filter( 'cartimize_get_shipping_details_address', array( $this, 'add_additional_shipping_fields' ), 10, 2 );
		}
	}

	function checkout_billing_fields( $fields ) {
		$cartimize               = Cartimize::instance();
		$unmodified_fields = WC()->countries->get_default_address_fields();

		$fields['billing_full_name']  = $unmodified_fields['full_name'];
		$fields['billing_full_name']['cartimize_row']  = 0;// First row
		if ( isset( $fields['billing_persontype'] ) ) {
			 $fields['billing_persontype']['cartimize_row'] = 1;
		}
		if ( isset( $fields['billing_cpf'] ) ) {
			 $fields['billing_cpf']['cartimize_row'] = 2;
			 $fields['billing_cpf']['cartimize_priority'] = 0;
		}
		if ( isset( $fields['billing_rg'] ) ) {
			 $fields['billing_rg']['cartimize_row'] = 2;
			 $fields['billing_rg']['cartimize_priority'] = 1;
		}
		if ( isset( $fields['billing_company'] ) ) {
			$fields['billing_company'] = $unmodified_fields['company'];
			$fields['billing_company']['cartimize_row'] = 3;
			$fields['billing_company']['cartimize_priority'] = 0;
			unset($fields['billing_company']['cartimize_optional_label']);
			unset($fields['billing_company']['is_hidden']);
		} 
		if ( isset( $fields['billing_cnpj'] ) ) {
			 $fields['billing_cnpj']['cartimize_row'] = 3;
			 $fields['billing_cnpj']['cartimize_priority'] = 1;
		}

		if ( isset( $fields['billing_ie'] ) ) {
			 $fields['billing_ie']['cartimize_row'] = 3;
			 $fields['billing_ie']['cartimize_priority'] = 2;
		}
		
		if ( isset( $fields['billing_birthdate'] ) ) {
			$fields['billing_birthdate']['columns'] = 12;
			$fields['billing_birthdate']['class']   = array();
			$fields['billing_birthdate']['cartimize_row']   = 4;
			$fields['billing_birthdate']['cartimize_priority']   = 0;
		}

		if ( isset( $fields['billing_sex'] ) ) {
			$fields['billing_sex']['columns'] = 12;
			$fields['billing_sex']['class']   = array();
			$fields['billing_sex']['cartimize_row']   = 4;
			$fields['billing_sex']['cartimize_priority']   = 1;
		}
		$fields['billing_address_1']  = $unmodified_fields['address_1'];
		$fields['billing_address_1']['cartimize_row'] = 5;
		$fields['billing_number']['columns']       = 12;
		$fields['billing_number']['class']         = array();
		$fields['billing_number']['cartimize_row'] = 6;
		$fields['billing_address_2']  = $unmodified_fields['address_2'];
		$fields['billing_address_2']['cartimize_row'] = 7;
		$fields['billing_neighborhood']['columns'] = 12;
		$fields['billing_neighborhood']['class']   = array();
		$fields['billing_neighborhood']['cartimize_row'] = 8;
		$fields['billing_neighborhood']['is_hidden'] = true;
		$fields['billing_neighborhood']['cartimize_optional_label'] = apply_filters( 'cartimize_neighborhood_optional_text', esc_html__( 'Add a neighborhood (Optional)', 'linear-checkout-for-woo-by-cartimize' ) );
		$fields['billing_city']     = $unmodified_fields['city'];
		$fields['billing_city']['cartimize_row']  = 9;
		$fields['billing_country']  = $unmodified_fields['country'];
		$fields['billing_country']['cartimize_row']  = 10;
		$fields['billing_postcode'] = $unmodified_fields['postcode'];
		$fields['billing_postcode']['cartimize_row']  = 10;
		$fields['billing_state']    = $unmodified_fields['state'];
		$fields['billing_state']['cartimize_row']  = 10;
		if ( !empty( $fields['billing_phone'] ) ) {
			$fields['billing_phone']['cartimize_row'] = 11;
			$fields['billing_phone']['cartimize_priority'] = 0;
		}

		if ( !empty( $fields['billing_cellphone'] ) ) {
			$fields['billing_cellphone']['columns']    = 11;
			$fields['billing_cellphone']['class']      = array();
			$fields['billing_cellphone']['cartimize_row'] = 11;
			$fields['billing_cellphone']['cartimize_priority'] = 1;
		}

		$fields['billing_first_name'] = $unmodified_fields['first_name'];
		$fields['billing_last_name']  = $unmodified_fields['last_name'];

		return $fields;
	}

	function checkout_shipping_fields( $fields ) {
		$cartimize               = Cartimize::instance();
		$unmodified_fields = WC()->countries->get_default_address_fields();

		$fields['shipping_full_name']  = $unmodified_fields['full_name'];
		if ( isset( $unmodified_fields['company'] ) ) {
			$fields['shipping_company'] = $unmodified_fields['company'];
		} else {
			unset( $fields['shipping_company'] );
		}
		$fields['shipping_address_1']  = $unmodified_fields['address_1'];
		$fields['shipping_number']['columns']       = 12;
		$fields['shipping_number']['class']         = array();
		$fields['shipping_number']['cartimize_row'] = 3;
		$fields['shipping_address_2']  = $unmodified_fields['address_2'];
		$fields['shipping_address_2']['cartimize_row'] = 4;
		$fields['shipping_neighborhood']['columns'] = 12;
		$fields['shipping_neighborhood']['class']   = array();
		$fields['shipping_neighborhood']['cartimize_row'] = 5;
		$fields['shipping_neighborhood']['is_hidden'] = true;
		$fields['shipping_neighborhood']['cartimize_optional_label']  = apply_filters( 'cartimize_neighborhood_optional_text', esc_html__( 'Add a neighborhood (Optional)', 'linear-checkout-for-woo-by-cartimize' ) );
		$fields['shipping_city']     = $unmodified_fields['city'];
		$fields['shipping_city']['cartimize_row'] = 6;
		$fields['shipping_country']  = $unmodified_fields['country'];
		$fields['shipping_country']['cartimize_row'] = 7;
		$fields['shipping_postcode'] = $unmodified_fields['postcode'];
		$fields['shipping_postcode']['cartimize_row'] = 7;
		$fields['shipping_state']    = $unmodified_fields['state'];
		$fields['shipping_state']['cartimize_row'] = 7;

		if ( $cartimize->is_phone_fields_enabled() && ! empty( $unmodified_fields['phone'] ) ) {
			$fields['shipping_phone'] = $unmodified_fields['phone'];
			$fields['shipping_phone']['cartimize_row'] = 8;
		}
		$fields['shipping_first_name'] = $unmodified_fields['first_name'];
		$fields['shipping_last_name']  = $unmodified_fields['last_name'];

		return $fields;
	}

	function typescript_class_and_params( $compatibility ) {
		$compatibility[] = [
			'class'  => 'ExtraCheckoutFieldsBrazil',
			'params' => [],
		];

		return $compatibility;
	}

	function wcbcf_checkout_billing_fields( $fields ){
		$unmodified_fields = WC()->countries->get_default_address_fields();

		$fields['billing_full_name'] = $unmodified_fields['full_name'];
		
		return $fields;
	}

	function wcbcf_checkout_shipping_fields( $fields ){
		$cartimize               = Cartimize::instance();
		$unmodified_fields = WC()->countries->get_default_address_fields();

		$fields['shipping_full_name'] = $unmodified_fields['full_name'];
		
		if ( $cartimize->is_phone_fields_enabled() && ! empty( $unmodified_fields['phone'] ) ) {
			$fields['shipping_phone'] = $unmodified_fields['phone'];
		}

		return $fields;
	}

	function add_additional_billing_fields( $fields, $checkout ){

		$fields['neighborhood'] =  $checkout->get_value( 'billing_neighborhood' );
		$fields['number'] =  $checkout->get_value( 'billing_number' );

		return $fields;
	}

	function add_additional_shipping_fields( $fields, $checkout ){

		$fields['neighborhood'] =  $checkout->get_value( 'shipping_neighborhood' );
		$fields['number'] =  $checkout->get_value( 'shipping_number' );

		return $fields;
	}
}
